@@ -3,9 +3,12 @@
 -- Most would make sense in the Debug.Trace module
 -- There are Template Haskell versions that show you file locaiton information
 module Debug.FileLocation
-  (debug, debugM, debugMsg, dbg, dbgMsg, trc, ltrace, ltraceM, strace, traceId)
+  (debug, debugM, debugMsg, dbg, dbgMsg, trc, ltrace, ltraceM, strace, traceId, __LOC__)
   where
 
+import Control.Applicative ((<$>), (<*>), pure)
+import Language.Haskell.TH (recConE, litE, stringL, integerL)
+import Language.Haskell.TH.Instances
 import Language.Haskell.TH.Syntax
 import Debug.Util
 import Debug.Trace (trace)
@@ -39,3 +42,11 @@ dbgM = do
   loc <- qLocation
   let prefix = "DEBUG: " ++ (locationToString loc) ++ " "
   [|(\_x -> ltraceM (prefix ++ show _x) _x)|]
+
+-- | Embed an expression of type Loc containing the location
+-- information for the place where it appears.  Could be used in
+-- custom Exception types and similar:
+--
+-- > throw $ MyException $__LOC__
+__LOC__ :: Q Exp
+__LOC__ = lift =<< location
